@@ -14,11 +14,11 @@
 # limitations under the License.
 
 import sys
-import datetime
 
 from swift.common.http import HTTP_OK, HTTP_PARTIAL_CONTENT, HTTP_NO_CONTENT
 from swift.common.swob import Range, content_range_header_value
 
+from swift3.utils import S3Timestamp
 from swift3.controllers.base import Controller
 from swift3.response import S3NotImplemented, InvalidRange, NoSuchKey
 
@@ -96,19 +96,15 @@ class ObjectController(Controller):
         """
         Handle PUT Object and PUT Object (Copy) request
         """
+        # set X-Timestamp by swift3 to use at copy resp body
+        req_timestamp = S3Timestamp.now()
+        req.headers['X-Timestamp'] = req_timestamp.internal
         req.check_copy_source(self.app)
         resp = req.get_response(self.app)
 
         if 'X-Amz-Copy-Source' in req.headers:
-            obj_timestamp = (datetime.datetime.fromtimestamp(
-                float(resp.environ['HTTP_X_TIMESTAMP']))
-                .isoformat())
-            if len(obj_timestamp) is 19:
-                obj_timestamp += '.000Z'
-            else:
-                obj_timestamp = obj_timestamp[:-3] + 'Z'
             resp.append_copy_resp_body(req.controller_name,
-                                       obj_timestamp)
+                                       req_timestamp.s3xmlformat)
 
             # delete object metadata from response
             for key in list(resp.headers.keys()):
@@ -127,6 +123,7 @@ class ObjectController(Controller):
         """
         try:
             query = req.gen_multipart_manifest_delete_query(self.app)
+            req.headers['Content-Type'] = None  # Ignore client content-type
             resp = req.get_response(self.app, query=query)
             if query and resp.status_int == HTTP_OK:
                 for chunk in resp.app_iter:
