@@ -18,6 +18,7 @@ from UserDict import DictMixin
 from functools import partial
 
 from swift.common import swob
+from swift.common.utils import config_true_value
 
 from swift3.utils import snake_to_camel, sysmeta_prefix
 from swift3.etree import Element, SubElement, tostring
@@ -34,9 +35,6 @@ class HeaderKey(str):
         if self.lower().startswith('x-amz-'):
             # AWS headers returned by S3 are lowercase.
             return self.lower()
-        if self.lower().startswith('x-rgw-'):
-            # ceph/s3tests expects the header is lowercase.
-            return self.lower()
         return str.title(self)
 
 
@@ -87,6 +85,7 @@ class Response(ResponseBase, swob.Response):
         sw_sysmeta_headers = swob.HeaderKeyDict()
         sw_headers = swob.HeaderKeyDict()
         headers = HeaderKeyDict()
+        self.is_slo = False
 
         for key, val in self.headers.iteritems():
             _key = key.lower()
@@ -104,14 +103,13 @@ class Response(ResponseBase, swob.Response):
                 headers['x-amz-meta-' + _key[14:]] = val
             elif _key in ('content-length', 'content-type',
                           'content-range', 'content-encoding',
-                          'etag', 'last-modified'):
+                          'content-disposition', 'content-language',
+                          'etag', 'last-modified', 'x-robots-tag',
+                          'cache-control', 'expires'):
                 headers[key] = val
-            elif _key == 'x-container-object-count':
-                # for ceph/s3tests
-                headers['x-rgw-object-count'] = val
-            elif _key == 'x-container-bytes-used':
-                # for ceph/s3tests
-                headers['x-rgw-bytes-used'] = val
+            elif _key == 'x-static-large-object':
+                # for delete slo
+                self.is_slo = config_true_value(val)
 
         self.headers = headers
         # Used for pure swift header handling at the request layer
@@ -177,7 +175,8 @@ class ErrorResponse(ResponseBase, swob.HTTPException):
 
         swob.HTTPException.__init__(self, status=self._status,
                                     app_iter=self._body_iter(),
-                                    content_type='text/xml', *args, **kwargs)
+                                    content_type='application/xml', *args,
+                                    **kwargs)
         self.headers = HeaderKeyDict(self.headers)
 
     def _body_iter(self):
