@@ -30,8 +30,8 @@ from swift3.request import MAX_32BIT_INT
 class TestSwift3Bucket(Swift3TestCase):
     def setup_objects(self):
         self.objects = (('rose', '2011-01-05T02:19:14.275290', 0, 303),
-                        ('viola', '2011-01-05T02:19:14.275290', 0, 3909),
-                        ('lily', '2011-01-05T02:19:14.275290', 0, 3909),
+                        ('viola', '2011-01-05T02:19:14.275290', '0', 3909),
+                        ('lily', '2011-01-05T02:19:14.275290', '0', '3909'),
                         ('with space', '2011-01-05T02:19:14.275290', 0, 390),
                         ('with%20space', '2011-01-05T02:19:14.275290', 0, 390))
 
@@ -52,7 +52,7 @@ class TestSwift3Bucket(Swift3TestCase):
                             {}, None)
         self.swift.register('GET', '/v1/AUTH_test/junk', swob.HTTPOk, {},
                             object_list)
-        self.swift.register('GET', '/v1/AUTH_test/junk_subdir', swob.HTTPOk,
+        self.swift.register('GET', '/v1/AUTH_test/junk-subdir', swob.HTTPOk,
                             {}, json.dumps(object_list_subdir))
 
     def setUp(self):
@@ -63,28 +63,33 @@ class TestSwift3Bucket(Swift3TestCase):
     def test_bucket_HEAD(self):
         req = Request.blank('/junk',
                             environ={'REQUEST_METHOD': 'HEAD'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
 
     def test_bucket_HEAD_error(self):
         req = Request.blank('/nojunk',
                             environ={'REQUEST_METHOD': 'HEAD'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '404')
+        self.assertEquals(body, '')  # sanifty
 
     def test_bucket_HEAD_slash(self):
         req = Request.blank('/junk/',
                             environ={'REQUEST_METHOD': 'HEAD'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
 
     def test_bucket_HEAD_slash_error(self):
         req = Request.blank('/nojunk/',
                             environ={'REQUEST_METHOD': 'HEAD'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '404')
 
@@ -103,7 +108,8 @@ class TestSwift3Bucket(Swift3TestCase):
         bucket_name = 'junk'
         req = Request.blank('/%s' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
 
@@ -116,17 +122,20 @@ class TestSwift3Bucket(Swift3TestCase):
         names = []
         for o in objects:
             names.append(o.find('./Key').text)
-            self.assertTrue(o.find('./LastModified').text.endswith('Z'))
+            self.assertEqual('2011-01-05T02:19:14.275Z',
+                             o.find('./LastModified').text)
+            self.assertEqual('"0"', o.find('./ETag').text)
 
         self.assertEquals(len(names), len(self.objects))
         for i in self.objects:
             self.assertTrue(i[0] in names)
 
     def test_bucket_GET_subdir(self):
-        bucket_name = 'junk_subdir'
+        bucket_name = 'junk-subdir'
         req = Request.blank('/%s' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
         elem = fromstring(body, 'ListBucketResult')
@@ -144,14 +153,16 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/%s?max-keys=5' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./IsTruncated').text, 'false')
 
         req = Request.blank('/%s?max-keys=4' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./IsTruncated').text, 'true')
@@ -161,7 +172,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/%s?max-keys=5' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./MaxKeys').text, '5')
@@ -172,7 +184,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/%s?max-keys=5000' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./MaxKeys').text, '5000')
@@ -186,7 +199,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/%s?max-keys=invalid' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
 
@@ -195,7 +209,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/%s?max-keys=-1' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
 
@@ -205,7 +220,8 @@ class TestSwift3Bucket(Swift3TestCase):
         req = Request.blank('/%s?max-keys=%s' %
                             (bucket_name, MAX_32BIT_INT + 1),
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
 
@@ -213,7 +229,8 @@ class TestSwift3Bucket(Swift3TestCase):
         bucket_name = 'junk'
         req = Request.blank('/%s?delimiter=a&marker=b&prefix=c' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./Prefix').text, 'c')
@@ -232,7 +249,8 @@ class TestSwift3Bucket(Swift3TestCase):
             '/%s?delimiter=\xef\xbc\xa1&marker=\xef\xbc\xa2&'
             'prefix=\xef\xbc\xa3' % bucket_name,
             environ={'REQUEST_METHOD': 'GET'},
-            headers={'Authorization': 'AWS test:tester:hmac'})
+            headers={'Authorization': 'AWS test:tester:hmac',
+                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         elem = fromstring(body, 'ListBucketResult')
         self.assertEquals(elem.find('./Prefix').text, '\xef\xbc\xa3')
@@ -249,7 +267,8 @@ class TestSwift3Bucket(Swift3TestCase):
         bucket_name = 'junk'
         req = Request.blank('/%s?delimiter=a&max-keys=2' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
         elem = fromstring(body, 'ListBucketResult')
@@ -258,10 +277,11 @@ class TestSwift3Bucket(Swift3TestCase):
         self.assertEquals(elem.find('./IsTruncated').text, 'true')
 
     def test_bucket_GET_subdir_with_delimiter_max_keys(self):
-        bucket_name = 'junk_subdir'
+        bucket_name = 'junk-subdir'
         req = Request.blank('/%s?delimiter=a&max-keys=1' % bucket_name,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
         elem = fromstring(body, 'ListBucketResult')
@@ -310,7 +330,19 @@ class TestSwift3Bucket(Swift3TestCase):
     def test_bucket_PUT(self):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
+        status, headers, body = self.call_swift3(req)
+        self.assertEquals(status.split()[0], '200')
+        self.assertEquals(headers['Location'], '/bucket')
+
+        # Apparently some clients will include a chunked transfer-encoding
+        # even with no body
+        req = Request.blank('/bucket',
+                            environ={'REQUEST_METHOD': 'PUT'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
+                                     'Transfer-Encoding': 'chunked'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
         self.assertEquals(headers['Location'], '/bucket')
@@ -323,7 +355,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=xml)
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -332,6 +365,7 @@ class TestSwift3Bucket(Swift3TestCase):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'X-Amz-Acl': 'public-read'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -348,6 +382,7 @@ class TestSwift3Bucket(Swift3TestCase):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'X-Amz-Acl': 'public-read'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -365,7 +400,8 @@ class TestSwift3Bucket(Swift3TestCase):
 
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=xml)
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body),
@@ -375,7 +411,8 @@ class TestSwift3Bucket(Swift3TestCase):
     def test_bucket_PUT_with_location_invalid_xml(self):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body='invalid_xml')
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'MalformedXML')
@@ -399,14 +436,16 @@ class TestSwift3Bucket(Swift3TestCase):
     def test_bucket_DELETE(self):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': 'DELETE'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '204')
 
     def _test_bucket_for_s3acl(self, method, account):
         req = Request.blank('/bucket',
                             environ={'REQUEST_METHOD': method},
-                            headers={'Authorization': 'AWS %s:hmac' % account})
+                            headers={'Authorization': 'AWS %s:hmac' % account,
+                                     'Date': self.get_date_header()})
 
         return self.call_swift3(req)
 
@@ -437,7 +476,8 @@ class TestSwift3Bucket(Swift3TestCase):
     def _test_bucket_GET_canned_acl(self, bucket):
         req = Request.blank('/%s' % bucket,
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS test:tester:hmac'})
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()})
 
         return self.call_swift3(req)
 
