@@ -70,12 +70,14 @@ def s3acl(func=None, s3acl_only=False):
                 message += failing_point
                 raise exc_type(message)
 
+        instance = args[0]
+
         if not s3acl_only:
             call_func()
+            instance.swift._calls = []
 
         with patch('swift3.cfg.CONF.s3_acl', True):
             owner = Owner('test:tester', 'test:tester')
-            instance = args[0]
             generate_s3acl_environ('test', instance.swift, owner)
             call_func(' (fail at s3_acl)')
 
@@ -166,7 +168,8 @@ class TestSwift3S3Acl(Swift3TestCase):
     def test_bucket_acl_PUT_with_other_owner(self):
         req = Request.blank('/bucket?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=tostring(
                                 ACLPrivate(
                                     Owner(id='test:other',
@@ -177,7 +180,8 @@ class TestSwift3S3Acl(Swift3TestCase):
     def test_object_acl_PUT_xml_error(self):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body="invalid xml")
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'MalformedACLError')
@@ -186,6 +190,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'private'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -194,6 +199,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'public-read'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -202,6 +208,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'public-read-write'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -210,6 +217,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'authenticated-read'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -218,6 +226,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'bucket-owner-read'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -226,6 +235,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'bucket-owner-full-control'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(status.split()[0], '200')
@@ -234,6 +244,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-acl': 'invalid'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
@@ -242,6 +253,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-' + permission:
                                      'id=test:tester'})
         return self.call_swift3(req)
@@ -274,6 +286,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-full-control':
                                      'id=test:tester'},
                             body=tostring(
@@ -287,6 +300,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-full-control':
                                      'id=test:tester',
                                      'x-amz-acl': 'public-read'})
@@ -297,6 +311,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-read': 'emailAddress=a@b.c'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'NotImplemented')
@@ -308,7 +323,8 @@ class TestSwift3S3Acl(Swift3TestCase):
         xml = _make_xml(grantee=grantee)
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=xml)
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'NotImplemented')
@@ -319,7 +335,8 @@ class TestSwift3S3Acl(Swift3TestCase):
         xml = _make_xml(grantee=grantee)
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=xml)
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'MalformedACLError')
@@ -328,6 +345,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-read':
                                      'uri="http://acs.amazonaws.com/groups/'
                                      'global/AuthenticatedUsers"'})
@@ -338,6 +356,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-read':
                                      'uri="http://acs.amazonaws.com/groups/'
                                      'global/AllUsers"'})
@@ -348,6 +367,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-read':
                                      'uri="http://localhost/"'})
         status, headers, body = self.call_swift3(req)
@@ -361,7 +381,8 @@ class TestSwift3S3Acl(Swift3TestCase):
 
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS test:tester:hmac'},
+                            headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header()},
                             body=xml)
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
@@ -370,6 +391,7 @@ class TestSwift3S3Acl(Swift3TestCase):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
                             headers={'Authorization': 'AWS test:tester:hmac',
+                                     'Date': self.get_date_header(),
                                      'x-amz-grant-read': 'key=value'})
         status, headers, body = self.call_swift3(req)
         self.assertEquals(self._get_error_code(body), 'InvalidArgument')
@@ -377,7 +399,8 @@ class TestSwift3S3Acl(Swift3TestCase):
     def _test_bucket_acl_GET(self, account):
         req = Request.blank('/bucket?acl',
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS %s:hmac' % account})
+                            headers={'Authorization': 'AWS %s:hmac' % account,
+                                     'Date': self.get_date_header()})
         return self.call_swift3(req)
 
     def test_bucket_acl_GET_without_permission(self):
@@ -400,7 +423,8 @@ class TestSwift3S3Acl(Swift3TestCase):
         acl = ACL(self.default_owner, [Grant(User(account), permission)])
         req = Request.blank('/bucket?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS %s:hmac' % account},
+                            headers={'Authorization': 'AWS %s:hmac' % account,
+                                     'Date': self.get_date_header()},
                             body=tostring(acl.elem()))
 
         return self.call_swift3(req)
@@ -424,7 +448,8 @@ class TestSwift3S3Acl(Swift3TestCase):
     def _test_object_acl_GET(self, account):
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'GET'},
-                            headers={'Authorization': 'AWS %s:hmac' % account})
+                            headers={'Authorization': 'AWS %s:hmac' % account,
+                                     'Date': self.get_date_header()})
         return self.call_swift3(req)
 
     def test_object_acl_GET_without_permission(self):
@@ -447,7 +472,8 @@ class TestSwift3S3Acl(Swift3TestCase):
         acl = ACL(self.default_owner, [Grant(User(account), permission)])
         req = Request.blank('/bucket/object?acl',
                             environ={'REQUEST_METHOD': 'PUT'},
-                            headers={'Authorization': 'AWS %s:hmac' % account},
+                            headers={'Authorization': 'AWS %s:hmac' % account,
+                                     'Date': self.get_date_header()},
                             body=tostring(acl.elem()))
 
         return self.call_swift3(req)
@@ -471,7 +497,7 @@ class TestSwift3S3Acl(Swift3TestCase):
     def test_s3acl_decorator(self):
         @s3acl
         def non_class_s3acl_error():
-            raise
+            raise TypeError()
 
         class FakeClass(object):
             def __init__(self):
@@ -479,7 +505,7 @@ class TestSwift3S3Acl(Swift3TestCase):
 
             @s3acl
             def s3acl_error(self):
-                raise
+                raise TypeError()
 
             @s3acl
             def s3acl_assert_fail(self):
@@ -488,12 +514,12 @@ class TestSwift3S3Acl(Swift3TestCase):
             @s3acl(s3acl_only=True)
             def s3acl_s3only_error(self):
                 if CONF.s3_acl:
-                    raise
+                    raise TypeError()
 
             @s3acl(s3acl_only=True)
             def s3acl_s3only_no_error(self):
                 if not CONF.s3_acl:
-                    raise
+                    raise TypeError()
 
         fake_class = FakeClass()
 
