@@ -16,6 +16,7 @@
 import re
 import uuid
 import base64
+import time
 
 
 from swift.common.utils import get_logger
@@ -135,3 +136,13 @@ def validate_bucket_name(name):
             return False
         else:
             return True
+
+
+class S3Timestamp(utils.Timestamp):
+    @property
+    def s3xmlformat(self):
+        return self.isoformat[:-7] + '.000Z'
+
+    @classmethod
+    def now(cls):
+        return cls(time.time())
